@@ -1,14 +1,11 @@
 use strict;
 use warnings;
-package Test::LWP::UserAgent;
-BEGIN {
-  $Test::LWP::UserAgent::AUTHORITY = 'cpan:ETHER';
-}
-# git description: v0.024-1-g06e4fcd
-$Test::LWP::UserAgent::VERSION = '0.025';
+package Test::LWP::UserAgent; # git description: v0.028-5-g225ef55
 # ABSTRACT: A LWP::UserAgent suitable for simulating and testing network calls
 # KEYWORDS: testing useragent networking mock server client
-# vim: set ts=8 sw=4 tw=78 et :
+# vim: set ts=8 sts=4 sw=4 tw=78 et :
+
+our $VERSION = '0.029';
 
 use parent 'LWP::UserAgent';
 use Scalar::Util qw(blessed reftype);
@@ -88,6 +85,7 @@ sub map_response
     {
         push @response_map, [ $request_description, $response ];
     }
+    return $self;
 }
 
 sub map_network_response
@@ -105,6 +103,7 @@ sub map_network_response
         push @response_map,
             [ $request_description, sub { LWP::UserAgent->new->send_request($_[0]) } ];
     }
+    return $self;
 }
 
 sub unmap_all
@@ -122,6 +121,7 @@ sub unmap_all
             if $instance_only;
         @response_map = ();
     }
+    return $self;
 }
 
 sub register_psgi
@@ -157,6 +157,7 @@ sub unregister_psgi
     {
         @response_map = grep { $_->[0] ne $domain } @response_map;
     }
+    return $self;
 }
 
 sub last_http_request_sent
@@ -342,7 +343,7 @@ Test::LWP::UserAgent - A LWP::UserAgent suitable for simulating and testing netw
 
 =head1 VERSION
 
-version 0.025
+version 0.029
 
 =head1 SYNOPSIS
 
@@ -532,6 +533,8 @@ Instance mappings take priority over global (class method) mappings - if no
 matches are found from mappings added to the instance, the global mappings are
 then examined. When no matches have been found, a 404 response is returned.
 
+This method returns the C<Test::LWP::UserAgent> object or class.
+
 =head2 C<map_network_response($request_description)>
 
 Same as C<map_response> above, only requests that match this description will
@@ -543,6 +546,8 @@ are used for making the real network call. If called as a class method, a
 pristine L<LWP::UserAgent> object with no customized options will be used
 instead.
 
+This method returns the C<Test::LWP::UserAgent> object or class.
+
 =head2 C<unmap_all(instance_only?)>
 
 When called as a class method, removes all mappings set up globally (across all
@@ -553,6 +558,8 @@ this instance, unless a true value is passed as an argument, in which only
 mappings local to the object will be removed. (Any true value will do, so you
 can pass a meaningful string.)
 
+This method returns the C<Test::LWP::UserAgent> object or class.
+
 =head2 C<register_psgi($domain, $app)>
 
 Register a particular L<PSGI> app (code reference) to be used when requests
@@ -577,6 +584,8 @@ a server so as to test your client code.
 You might find using L<Plack::Test> or L<Plack::Test::ExternalServer> easier
 for your needs, so check those out as well.
 
+This method returns the C<Test::LWP::UserAgent> object or class.
+
 =head2 C<unregister_psgi($domain, instance_only?)>
 
 When called as a class method, removes a domain->PSGI app entry that had been
@@ -593,6 +602,8 @@ then add C<undef> as a mapping on your instance:
 
     $useragent->map_response($domain, undef);
 
+This method returns the C<Test::LWP::UserAgent> object or class.
+
 =head2 C<last_http_request_sent>
 
 The last L<HTTP::Request> object that this object (if called on an object) or
@@ -725,6 +736,10 @@ L<Test::Mock::LWP::UserAgent>
 
 =item *
 
+L<URI>, L<HTTP::Request>, L<HTTP::Response>
+
+=item *
+
 L<LWP::UserAgent>
 
 =item *
@@ -748,4 +763,10 @@ This software is copyright (c) 2012 by Karen Etheridge.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 CONTRIBUTOR
+
+=for stopwords Tom Hukins
+
+Tom Hukins <tom@eborcom.com>
+
 =cut
